==> pyrix-0.7.17rc1.tar.gz: pyrix-0.7.17rc1/README.md <==
# **Pyrix** : The Minimalist Matrix Library
[![PyPI](https://img.shields.io/pypi/v/pyrix?style=flat-square&logo=pypi)](https://pypi.org/project/pyrix/#description)
[![GitHub](https://img.shields.io/github/license/Abhi-1U/pyrix?style=flat-square&logo=github)](https://github.com/Abhi-1U/pyrix/blob/master/LICENSE)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/pyrix?style=flat-square&logo=python)](https://pypi.org/project/pyrix/#description)
[![Code Style](https://img.shields.io/badge/code%20style-black-black?style=flat-square)](https://github.com/psf/black)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/pyrix?color=navy&style=flat-square)](https://pypi.org/project/pyrix/#files)
[![Codecov](https://img.shields.io/codecov/c/github/Abhi-1U/pyrix?style=flat-square&logo=codecov)](https://codecov.io/gh/Abhi-1U/pyrix)
[![Travis (.org)](https://img.shields.io/travis/Abhi-1U/pyrix?style=flat-square&logo=travis)](https://travis-ci.org/Abhi-1U/pyrix)  
### A different take on Matrices
Matrices are everywhere and the central most important aspect of computing. Be
it graphics, AI or cryptography Matrix plays an important role and Pyrix takes
on with the pure Python matrix implementation.

### Why Pyrix?
As computaional Mathematics has evolved we have reached a stage where
traditional pen/paper mathematics is becoming more of a tradition. For example
in the recent courses at MIT for Linear Algebra-18.06 Most lectures are focused
on explaining abstract ideas and methods. For the most Part Computers have
proven to be a lot faster to do large computations and with a precise, accurate
solution.  
I pitch Pyrix to be a Well implemented, Fast Performing Library to enable other
students to learn Linear Algebra and Matrix Mathematics alongside. Being a
student it's often a struggle to adopt to computational mathematics. Some
courses leave students at an abstract view of concepts and its always upto the
student to explore further.   
With pyrix being Open-Source One can easily view the source code, understand how
 the matrix operations are performed within the computer.
### Getting Started with Pyrix

For Python3 enviornment one can install the package with pip  
```
$ pip install pyrix
```  
\* some operating systems see pip for Python2 and pip3 for Python3 ,in that case  
```
$ pip3 install pyrix
```

==> pyrix-0.7.19.tar.gz: pyrix-0.7.19/README.md <==
![Pyrix](template.png)
# **Pyrix** : The Minimalist Matrix Library
[![PyPI](https://img.shields.io/pypi/v/pyrix?style=flat-square&logo=pypi)](https://pypi.org/project/pyrix/#description)
[![GitHub](https://img.shields.io/github/license/Abhi-1U/pyrix?style=flat-square&logo=github)](https://github.com/Abhi-1U/pyrix/blob/master/LICENSE)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/pyrix?style=flat-square&logo=python)](https://pypi.org/project/pyrix/#description)
[![Code Style](https://img.shields.io/badge/code%20style-black-black?style=flat-square)](https://github.com/psf/black)
[![Downloads](https://static.pepy.tech/personalized-badge/pyrix?period=total&units=international_system&left_color=blue&right_color=orange&left_text=Downloads)](https://pepy.tech/project/pyrix)
[![Codecov](https://img.shields.io/codecov/c/github/Abhi-1U/pyrix?style=flat-square&logo=codecov)](https://codecov.io/gh/Abhi-1U/pyrix)
[![Travis (.org)](https://img.shields.io/travis/Abhi-1U/pyrix?style=flat-square&logo=travis)](https://travis-ci.org/Abhi-1U/pyrix)  
### A different take on Matrices
Matrices are everywhere and the central most important aspect of computing. Be
it graphics, AI or cryptography Matrix plays an important role and Pyrix takes
on with the pure Python matrix implementation.

### Why Pyrix?
As computaional Mathematics has evolved we have reached a stage where
traditional pen/paper mathematics is becoming more of a tradition. For example
in the recent courses at MIT for Linear Algebra-18.06 Most lectures are focused
on explaining abstract ideas and methods. For the most Part Computers have
proven to be a lot faster to do large computations and with a precise, accurate
solution.  
I pitch Pyrix to be a Well implemented, Fast Performing Library to enable other
students to learn Linear Algebra and Matrix Mathematics alongside. Being a
student it's often a struggle to adopt to computational mathematics. Some
courses leave students at an abstract view of concepts and its always upto the
student to explore further.   
With pyrix being Open-Source One can easily view the source code, understand how
 the matrix operations are performed within the computer.
### Getting Started with Pyrix

For Python3 enviornment one can install the package with pip  
```
$ pip install pyrix
```  
\* some operating systems see pip for Python2 and pip3 for Python3 ,in that case  
```
$ pip3 install pyrix
```
